@@ -28,7 +28,7 @@ class Vingd:
     URL_FRONTEND = "https://www.vingd.com"
     # sandbox urls
     URL_ENDPOINT_SANDBOX = "https://api.vingd.com/sandbox/broker/v1"
-    URL_FRONTEND_SANDBOX = "http://www.sandbox.vingd.com"
+    URL_FRONTEND_SANDBOX = "https://www.sandbox.vingd.com"
     
     EXP_ORDER = {'minutes': 15}
     EXP_VOUCHER = {'days': 7}
@@ -479,7 +479,7 @@ class Vingd:
         """
         return self.request('get', 'id/users')
     
-    def get_user_balance(self):
+    def get_account_balance(self):
         """
         FETCHES the account balance for the authenticated user.
         
@@ -488,11 +488,70 @@ class Vingd:
         :raises GeneralException:
         :resource: ``fort/accounts/``
         
-        :access: authorized users; only authenticated user's account data can be
+        :access: authorized users; authenticated user's account data will be
             fetched
         """
         return int(self.request('get', 'fort/accounts')['balance'])
     
+    def authorized_get_account_balance(self, huid):
+        """
+        FETCHES the account balance for the user defined with `huid`.
+        
+        :rtype: ``bigint``
+        :returns: ``<amount_in_cents>``
+        :raises GeneralException:
+        :resource: ``fort/accounts/<huid>``
+        
+        :access: authorized users; delegate permission required for the
+            requester to read user's balance: ``get.account.balance``
+        """
+        return int(self.request('get', 'fort/accounts/%s' % huid)['balance'])
+    
+    def authorized_purchase_object(self, oid, price, huid):
+        """Does delegated (pre-authorized) purchase of `oid` in the name of
+        `huid`, at price `price` (vingd transferred from `huid` to consumer's
+        acc).
+        
+        :raises GeneralException:
+        :resource: ``objects/<oid>/purchases``
+        
+        :access: authorized users with ACL flag ``purchase.object.authorize`` +
+            delegate permission required for the requester to charge the
+            user: ``purchase.object``
+        """
+        return self.request('post', 'objects/%d/purchases' % oid, json.dumps({
+            'price': price,
+            'huid': huid,
+            'autocommit': True
+        }))
+    
+    def authorized_create_user(self, identities, primary, permissions=None):
+        """Creates Vingd user (profile & account), links it with the provided
+        identities (to be verified later), and sets the delegate-user
+        permissions (creator being the delegate). Returns Vingd user's `huid`
+        (hashed user id).
+        
+        Example::
+        
+            vingd.authorized_create_user(
+                identities={"facebook": "12312312", "mail": "user@example.com"},
+                primary="facebook",
+                delegate_permissions=["get.account.balance", "purchase.object"]
+            )
+        
+        :rtype: ``string``
+        :returns: ``<huid>``
+        :raises GeneralException:
+        :resource: ``id/objects/<oid>/purchases``
+        
+        :access: authorized users with ACL flag ``user.create``
+        """
+        return self.request('post', 'id/users/', json.dumps({
+            'identities': identities,
+            'primary_identity': primary,
+            'delegate_permissions': permissions
+        }))
+    
     def reward_user(self, huid_to, amount, description=None):
         """
         PERFORMS a single reward. User defined with `huid_to` is rewarded with
